#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-CFSbc1LDBxC2Z3K1VP3TYo
key:                  authenticate-1.3.5.2-CFSbc1LDBxC2Z3K1VP3TYo
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  09d1332ff7f85ba7f234a406de856334
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-CFSbc1LDBxC2Z3K1VP3TYo
depends:
    aeson-2.2.1.0-IFj7FSeQ5R79PZnh3ksXrW
    attoparsec-0.14.4-3CmiIm11iun2BHKDR4ovn7
    attoparsec-aeson-2.2.0.0-4Tlilqx2rNRLKS9o42toNZ base-4.18.2.1
    blaze-builder-0.4.4.1-4QmQvMAPyoDG7cxlUmp9Pw bytestring-0.11.5.3
    case-insensitive-1.2.1.0-L8b71mleMbHJVaC8zF8N1a
    conduit-1.3.6.1-1yIrQJAoba7Gda6MAs4N1q containers-0.6.7
    html-conduit-1.3.2.2-4nwnZY3S3BuHXGEk5oK2wl
    http-conduit-2.3.9.1-1jgAUVyqkxJ6z3Pvba5xG2
    http-types-0.12.4-4tdX51H3YCXI63KUlr8q5w
    network-uri-2.6.4.2-1K7fB5RWUkvJzcj2EjtnE4
    resourcet-1.2.6-GrVaNPG3RF7IMcvlKlmJk8 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq
    xml-conduit-1.9.1.4-9O7VQbNwRmb985lnsjzGmX

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

